@@ -1,9 +1,9 @@
-from django.utils import timezone
 from django.db import transaction
+from django.utils import timezone
 
-from . import populate_history
 from ... import models, utils
 from ...exceptions import NotHistoricalModelError
+from . import populate_history
 
 
 class Command(populate_history.Command):
@@ -60,7 +60,7 @@ class Command(populate_history.Command):
             history_model_manager = history_model_manager.filter(
                 history_date__lt=start_date
             )
-            found = len(history_model_manager)
+            found = history_model_manager.count()
             self.log("{0} has {1} old historical entries".format(model, found), 2)
             if not found:
                 continue
