@@ -1,13 +1,8 @@
-from __future__ import unicode_literals
-
 import copy
 import importlib
-import threading
 import uuid
 import warnings
 
-import django
-import six
 from django.apps import apps
 from django.conf import settings
 from django.contrib import admin
@@ -18,21 +13,22 @@ from django.db.models import ManyToManyField, Q
 from django.db.models.fields.proxy import OrderWrt
 from django.forms.models import model_to_dict
 from django.urls import reverse
-from django.utils.text import format_lazy
 from django.utils import timezone
+from django.utils.encoding import smart_str
+from django.utils.text import format_lazy
+from django.utils.translation import gettext_lazy as _
+
 from simple_history import utils
+
 from . import exceptions
 from .manager import HistoryDescriptor
 from .signals import post_create_historical_record, pre_create_historical_record
 from .utils import get_change_reason_from_object
 
-if django.VERSION < (2,):
-    from django.utils.translation import ugettext_lazy as _
-    from django.utils.encoding import smart_text as smart_str
-    from django.utils.encoding import python_2_unicode_compatible
-else:
-    from django.utils.translation import gettext_lazy as _
-    from django.utils.encoding import smart_str
+try:
+    from asgiref.local import Local as LocalContext
+except ImportError:
+    from threading import local as LocalContext
 
 registered_models = {}
 
@@ -59,8 +55,8 @@ def _history_user_setter(historical_instance, user):
         historical_instance.history_user_id = user.pk
 
 
-class HistoricalRecords(object):
-    thread = threading.local()
+class HistoricalRecords:
+    thread = context = LocalContext()  # retain thread for backwards compatibility
 
     def __init__(
         self,
@@ -106,7 +102,7 @@ class HistoricalRecords(object):
             excluded_fields = []
         self.excluded_fields = excluded_fields
         try:
-            if isinstance(bases, six.string_types):
+            if isinstance(bases, str):
                 raise TypeError
             self.bases = (HistoricalChanges,) + tuple(bases)
         except TypeError:
@@ -230,11 +226,7 @@ class HistoricalRecords(object):
 
         registered_models[model._meta.db_table] = model
         history_model = type(str(name), self.bases, attrs)
-        return (
-            python_2_unicode_compatible(history_model)
-            if django.VERSION < (2,)
-            else history_model
-        )
+        return history_model
 
     def fields_included(self, model):
         fields = []
@@ -510,7 +502,7 @@ class HistoricalRecords(object):
             history_type=history_type,
             history_user=history_user,
             history_change_reason=history_change_reason,
-            **attrs
+            **attrs,
         )
 
         pre_create_historical_record.send(
@@ -542,8 +534,8 @@ class HistoricalRecords(object):
         except AttributeError:
             request = None
             try:
-                if self.thread.request.user.is_authenticated:
-                    request = self.thread.request
+                if self.context.request.user.is_authenticated:
+                    request = self.context.request
             except AttributeError:
                 pass
 
@@ -568,6 +560,9 @@ def transform_field(field):
     # Historical instance shouldn't change create/update timestamps
     field.auto_now = False
     field.auto_now_add = False
+    # Just setting db_collation explicitly since we're not using
+    # field.deconstruct() here
+    field.db_collation = None
 
     if field.primary_key or field.unique:
         # Unique fields can no longer be guaranteed unique,
@@ -578,7 +573,7 @@ def transform_field(field):
         field.serialize = True
 
 
-class HistoricalObjectDescriptor(object):
+class HistoricalObjectDescriptor:
     def __init__(self, model, fields_included):
         self.model = model
         self.fields_included = fields_included
@@ -588,7 +583,7 @@ class HistoricalObjectDescriptor(object):
         return self.model(**values)
 
 
-class HistoricalChanges(object):
+class HistoricalChanges:
     def diff_against(self, old_history, excluded_fields=None):
         if not isinstance(old_history, type(self)):
             raise TypeError(
@@ -615,14 +610,14 @@ class HistoricalChanges(object):
         return ModelDelta(changes, changed_fields, old_history, self)
 
 
-class ModelChange(object):
+class ModelChange:
     def __init__(self, field_name, old_value, new_value):
         self.field = field_name
         self.old = old_value
         self.new = new_value
 
 
-class ModelDelta(object):
+class ModelDelta:
     def __init__(self, changes, changed_fields, old_record, new_record):
         self.changes = changes
         self.changed_fields = changed_fields
