@@ -49,6 +49,7 @@ def bulk_create_with_history(
     objs,
     model,
     batch_size=None,
+    ignore_conflicts=False,
     default_user=None,
     default_change_reason=None,
     default_date=None,
@@ -82,8 +83,10 @@ def bulk_create_with_history(
 
     second_transaction_required = True
     with transaction.atomic(savepoint=False):
-        objs_with_id = model_manager.bulk_create(objs, batch_size=batch_size)
-        if objs_with_id and objs_with_id[0].pk:
+        objs_with_id = model_manager.bulk_create(
+            objs, batch_size=batch_size, ignore_conflicts=ignore_conflicts
+        )
+        if objs_with_id and objs_with_id[0].pk and not ignore_conflicts:
             second_transaction_required = False
             history_manager.bulk_history_create(
                 objs_with_id,
@@ -140,11 +143,6 @@ def bulk_update_with_history(
     :param manager: Optional model manager to use for the model instead of the default
         manager
     """
-    if django.VERSION < (2, 2,):
-        raise NotImplementedError(
-            "bulk_update_with_history is only available on "
-            "Django versions 2.2 and later"
-        )
     history_manager = get_history_manager_for_model(model)
     model_manager = manager or model._default_manager
     if model_manager.model is not model:
@@ -166,13 +164,4 @@ def get_change_reason_from_object(obj):
     if hasattr(obj, "_change_reason"):
         return getattr(obj, "_change_reason")
 
-    if hasattr(obj, "changeReason"):
-        warning_msg = (
-            "Using the attr changeReason to populate history_change_reason is"
-            " deprecated in 2.10.0 and will be removed in 3.0.0. Use "
-            "_change_reason instead. "
-        )
-        warnings.warn(warning_msg, DeprecationWarning)
-        return getattr(obj, "changeReason")
-
     return None
